%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1. Set up the model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% 1.1 Parameters of the economy
%
format long;
% Preference            
beta   = 0.8;                % subjective discount factor

% production function
alpha  = 2/3;                % labor share              
ce  = 30:0.1:40;             % entry sunk cost
cf  = 20;                    % production fixed cost

% demand of output
D = 100;

% supply of labor
N = 100;

% exogenous shock
nz = 101;
rrho = 0.9;
ssigma = 0.2;
logzbar = 1.4;
[prob,~,logz] = tauchen(nz,logzbar,rrho,ssigma);
z = exp(logz);
g = invdist(prob);

% wage bounds
wgridMin = 0.2;
wgridMax = 0.3;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2. Solve the model
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
ce_cell = num2cell(ce);
t1 = tic;
[z_cut,w,p,m,mu_inter] = cellfun(@(x) solve_Hopenhayn(beta,alpha,x,cf,D,N,nz,z,g,prob,wgridMin,wgridMax),...
    ce_cell,'UniformOutput',false);
t2 = toc(t1);
z_cut = cell2mat(z_cut);
w = cell2mat(w);
p = cell2mat(p);
m = cell2mat(m);
save('result.mat');
fprintf(1,'Time Spent in Equilibrium Computation: %14.4g Seconds\n',t2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3. Plot the comparative static results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
hh = figure;
set(gca,'FontName','Times New Roman');
sgtitle('\fontname{Times New Roman}Comparative Static Results for Entry Cost','FontSize',16);
% plot 1
figure(hh);   
subplot(2,3,1);
plot(ce,z_cut);
xlabel('Entry Cost $c_{e}$','Interpreter','latex'); 
ylabel('Exit Threshold $a^{*}$','Interpreter','latex');
% plot 2
figure(hh);   
subplot(2,3,2);
plot(ce,w);
xlabel('Entry Cost $c_{e}$','Interpreter','latex'); 
ylabel('Labor Wage $w^{*}$','Interpreter','latex');
% plot 3
figure(hh);   
subplot(2,3,3);
plot(ce,p);
xlabel('Entry Cost $c_{e}$','Interpreter','latex'); 
ylabel('Output Price $p^{*}$','Interpreter','latex');
% plot 4
figure(hh);   
subplot(2,3,4);
plot(ce,m);
xlabel('Entry Cost $c_{e}$','Interpreter','latex'); 
ylabel('Entrants'' mass $m^{*}$','Interpreter','latex');
% plot 5
figure(hh);   
subplot(2,3,5);
plot(ce,m./cell2mat(cellfun(@(x) sum(x),mu_inter,'UniformOutput',false)));
xlabel('Entry Cost $c_{e}$','Interpreter','latex'); 
ylabel('Entry/Exit Rate $m^{*}/\mu^{*}$','Interpreter','latex');
% plot 6
figure(hh);   
subplot(2,3,6);
leg_str = num2cell(zeros(length(find(ce==fix(ce))),1));
j = 1;
for i = 1:length(ce)
    p = plot(z,mu_inter{i});
    if ce(i) == fix(ce(i))
        leg_str{j} = ['$c_{e}$ = ',num2str(ce(i))];
        j = j+1;
    else
        set(p,'handlevisibility','off');
    end
    hold on;
end
legend(leg_str,'Interpreter','latex');
hold off;
xlabel('Idiosyncratic Productivity $a$','Interpreter','latex'); 
ylabel('Density $\mu^{*}$','Interpreter','latex');







